//
// Copyright (c) 2016, MindFusion LLC - Bulgaria.
//

using System;
using System.Drawing;
using System.Windows.Forms;


namespace MindFusion.Scheduling.WinForms.Samples.CS.Effects
{
	/// <summary>
	/// Summary description for MainForm.
	/// </summary>
	public partial class MainForm : Form
	{
		/// <summary>
		/// Initializes a new instance of the MainForm class.
		/// </summary>
		public MainForm()
		{
			InitializeComponent();

			_appPath = System.IO.Path.GetDirectoryName(Application.ExecutablePath);

			_lbInfo.DocumentText = Properties.Resources.Info;
			_lbInfo.DocumentCompleted += new WebBrowserDocumentCompletedEventHandler(OnDocumentCompleted);

			glassEffect = new GlassEffect();
			aeroEffect = new AeroEffect();

			// Defaults
			_schedule.BeginInit();
			_schedule.ItemSettings.ShadowStyle = ShadowStyle.None;
			_schedule.ItemSettings.Size = 24;
			_schedule.TimetableSettings.Dates.Clear();
			_schedule.TimetableSettings.Dates.Add(DateTime.Today);
			_schedule.TimetableSettings.Dates.Add(DateTime.Today.AddDays(1));
			_schedule.TimetableSettings.ShowDayHeader = State.Enabled;
			_schedule.EndInit();

			// Create some preview items
			Appointment app;

			app = new Appointment();
			app.StartTime = DateTime.Today;
			app.EndTime = DateTime.Today;
			app.AllDayEvent = true;
			app.HeaderText = "All-day appointment";
			_schedule.Schedule.Items.Add(app);

			app = new Appointment();
			app.StartTime = DateTime.Today.AddHours(2);
			app.EndTime = DateTime.Today.AddHours(4);
			app.HeaderText = "Event #1";
			app.DescriptionText = "Description for Event #1.";
			_schedule.Schedule.Items.Add(app);

			app = new Appointment();
			app.StartTime = DateTime.Today.AddHours(3);
			app.EndTime = DateTime.Today.AddHours(4.5);
			app.HeaderText = "Event #2";
			app.DescriptionText = "Description for Event #2.";
			_schedule.Schedule.Items.Add(app);

			app = new Appointment();
			app.StartTime = DateTime.Today.AddHours(5);
			app.EndTime = DateTime.Today.AddHours(6);
			app.HeaderText = "Event #3";
			app.DescriptionText = "Description for Event #3.";
			_schedule.Schedule.Items.Add(app);

			// Presets
			defaultPreset = new Preset();
			defaultPreset.Name = "(Default)";
			defaultPreset.UseGlassEffect = false;
			defaultPreset.GlassEffectType = GlassEffectType.Type1;
			defaultPreset.UsePenAsGlow = false;
			defaultPreset.GlowColor = Color.White;
			defaultPreset.ReflectionColor = Color.White;
			defaultPreset.UseAeroEffect = false;
			defaultPreset.Opacity = 40;
			defaultPreset.InnerOutlineColor = Color.White;
			defaultPreset.ShadeColor = Color.Black;
			defaultPreset.OverridesThemeSettings = true;
			defaultPreset.CalendarBackground = Color.White;
			defaultPreset.CalendarBorder = Color.DarkSlateGray;
			defaultPreset.ItemBorder = Color.DarkSlateGray;
			defaultPreset.ItemBackground1 = Color.LightSteelBlue;
			defaultPreset.UseItemBackground2 = false;
			defaultPreset.ItemBackground2 = Color.White;
			defaultPreset.Theme = ThemeType.Standard;
			ApplyPreset(defaultPreset);

			Preset preset = new Preset();
			preset.Name = "Glass & Aero (Windows2003 Theme)";
			preset.UseGlassEffect = true;
			preset.GlassEffectType = GlassEffectType.Type1;
			preset.UsePenAsGlow = false;
			preset.GlowColor = Color.White;
			preset.ReflectionColor = Color.White;
			preset.UseAeroEffect = true;
			preset.Opacity = 40;
			preset.InnerOutlineColor = Color.White;
			preset.ShadeColor = Color.Black;
			preset.OverridesThemeSettings = false;
			preset.CalendarBackground = Color.White;
			preset.CalendarBorder = Color.DarkSlateGray;
			preset.ItemBorder = Color.DarkSlateGray;
			preset.ItemBackground1 = Color.LightSteelBlue;
			preset.UseItemBackground2 = false;
			preset.ItemBackground2 = Color.White;
			preset.Theme = ThemeType.Windows2003;
			AddToList(preset);

			preset = new Preset();
			preset.Name = "Glass & Aero (Lila Theme)";
			preset.UseGlassEffect = true;
			preset.GlassEffectType = GlassEffectType.Type1;
			preset.UsePenAsGlow = false;
			preset.GlowColor = Color.White;
			preset.ReflectionColor = Color.White;
			preset.UseAeroEffect = true;
			preset.Opacity = 40;
			preset.InnerOutlineColor = Color.White;
			preset.ShadeColor = Color.Black;
			preset.OverridesThemeSettings = false;
			preset.CalendarBackground = Color.White;
			preset.CalendarBorder = Color.DarkSlateGray;
			preset.ItemBorder = Color.DarkSlateGray;
			preset.ItemBackground1 = Color.LightSteelBlue;
			preset.UseItemBackground2 = false;
			preset.ItemBackground2 = Color.White;
			preset.Theme = ThemeType.Lila;
			AddToList(preset);

			preset = new Preset();
			preset.Name = "Glass & Aero (Silver Theme)";
			preset.UseGlassEffect = true;
			preset.GlassEffectType = GlassEffectType.Type1;
			preset.UsePenAsGlow = false;
			preset.GlowColor = Color.White;
			preset.ReflectionColor = Color.White;
			preset.UseAeroEffect = true;
			preset.Opacity = 40;
			preset.InnerOutlineColor = Color.White;
			preset.ShadeColor = Color.Black;
			preset.OverridesThemeSettings = false;
			preset.CalendarBackground = Color.White;
			preset.CalendarBorder = Color.DarkSlateGray;
			preset.ItemBorder = Color.DarkSlateGray;
			preset.ItemBackground1 = Color.LightSteelBlue;
			preset.UseItemBackground2 = false;
			preset.ItemBackground2 = Color.White;
			preset.Theme = ThemeType.Silver;
			AddToList(preset);

			preset = new Preset();
			preset.Name = "Glass & Aero (Vista Theme)";
			preset.UseGlassEffect = true;
			preset.GlassEffectType = GlassEffectType.Type1;
			preset.UsePenAsGlow = false;
			preset.GlowColor = Color.White;
			preset.ReflectionColor = Color.White;
			preset.UseAeroEffect = true;
			preset.Opacity = 40;
			preset.InnerOutlineColor = Color.White;
			preset.ShadeColor = Color.Black;
			preset.OverridesThemeSettings = false;
			preset.CalendarBackground = Color.White;
			preset.CalendarBorder = Color.DarkSlateGray;
			preset.ItemBorder = Color.DarkSlateGray;
			preset.ItemBackground1 = Color.LightSteelBlue;
			preset.UseItemBackground2 = false;
			preset.ItemBackground2 = Color.White;
			preset.Theme = ThemeType.Vista;
			AddToList(preset);

			preset = new Preset();
			preset.Name = "Glass (Default Colors)";
			preset.UseGlassEffect = true;
			preset.GlassEffectType = GlassEffectType.Type1;
			preset.UsePenAsGlow = false;
			preset.GlowColor = Color.White;
			preset.ReflectionColor = Color.White;
			preset.UseAeroEffect = false;
			preset.Opacity = 40;
			preset.InnerOutlineColor = Color.White;
			preset.ShadeColor = Color.Black;
			preset.OverridesThemeSettings = true;
			preset.CalendarBackground = Color.White;
			preset.CalendarBorder = Color.DarkSlateGray;
			preset.ItemBorder = Color.DarkSlateGray;
			preset.ItemBackground1 = Color.LightSteelBlue;
			preset.UseItemBackground2 = false;
			preset.ItemBackground2 = Color.White;
			preset.Theme = ThemeType.Standard;
			AddToList(preset);

			preset = new Preset();
			preset.Name = "Glass & Aero (Orange Background)";
			preset.UseGlassEffect = true;
			preset.GlassEffectType = GlassEffectType.Type2;
			preset.UsePenAsGlow = false;
			preset.GlowColor = Color.White;
			preset.ReflectionColor = Color.White;
			preset.UseAeroEffect = true;
			preset.Opacity = 20;
			preset.InnerOutlineColor = Color.White;
			preset.ShadeColor = Color.Black;
			preset.OverridesThemeSettings = true;
			preset.CalendarBackground = Color.Orange;
			preset.CalendarBorder = Color.DarkGoldenrod;
			preset.ItemBorder = Color.DarkSlateGray;
			preset.ItemBackground1 = Color.LightSteelBlue;
			preset.UseItemBackground2 = false;
			preset.ItemBackground2 = Color.White;
			preset.Theme = ThemeType.Standard;
			AddToList(preset);

			preset = new Preset();
			preset.Name = "Metalic";
			preset.UseGlassEffect = true;
			preset.GlassEffectType = GlassEffectType.Type2;
			preset.UsePenAsGlow = true;
			preset.GlowColor = Color.White;
			preset.ReflectionColor = Color.White;
			preset.UseAeroEffect = true;
			preset.Opacity = 50;
			preset.InnerOutlineColor = Color.White;
			preset.ShadeColor = Color.Black;
			preset.OverridesThemeSettings = true;
			preset.CalendarBackground = Color.FromArgb(0xC0, 0xC0, 0xC0);
			preset.CalendarBorder = Color.DarkSlateGray;
			preset.ItemBorder = Color.DarkSlateGray;
			preset.ItemBackground1 = Color.LightSteelBlue;
			preset.UseItemBackground2 = false;
			preset.ItemBackground2 = Color.White;
			preset.Theme = ThemeType.Standard;
			AddToList(preset);

			preset = new Preset();
			preset.Name = "Neon Glow";
			preset.UseGlassEffect = true;
			preset.GlassEffectType = GlassEffectType.Type2;
			preset.UsePenAsGlow = true;
			preset.GlowColor = Color.White;
			preset.ReflectionColor = Color.White;
			preset.UseAeroEffect = true;
			preset.Opacity = 0;
			preset.InnerOutlineColor = Color.Black;
			preset.ShadeColor = Color.FromArgb(0x80, 0xFF, 0xFF);
			preset.OverridesThemeSettings = true;
			preset.CalendarBackground = Color.Black;
			preset.CalendarBorder = Color.FromArgb(0x80, 0xFF, 0xFF);
			preset.ItemBorder = Color.FromArgb(0x80, 0xFF, 0xFF);
			preset.ItemBackground1 = Color.Black;
			preset.UseItemBackground2 = false;
			preset.ItemBackground2 = Color.White;
			preset.Theme = ThemeType.Standard;
			AddToList(preset);

			preset = new Preset();
			preset.Name = "Gray glass";
			preset.UseGlassEffect = true;
			preset.GlassEffectType = GlassEffectType.Type3;
			preset.UsePenAsGlow = false;
			preset.GlowColor = Color.White;
			preset.ReflectionColor = Color.White;
			preset.UseAeroEffect = true;
			preset.Opacity = 40;
			preset.InnerOutlineColor = Color.White;
			preset.ShadeColor = Color.Black;
			preset.OverridesThemeSettings = true;
			preset.CalendarBackground = Color.Gray;
			preset.CalendarBorder = Color.Black;
			preset.ItemBorder = Color.Black;
			preset.ItemBackground1 = Color.LightCyan;
			preset.UseItemBackground2 = true;
			preset.ItemBackground2 = Color.FromArgb(0xA8, 0xBF, 0xBF);
			preset.Theme = ThemeType.Standard;
			AddToList(preset);

			preset = new Preset();
			preset.Name = "Brown";
			preset.UseGlassEffect = true;
			preset.GlassEffectType = GlassEffectType.Type1;
			preset.UsePenAsGlow = false;
			preset.GlowColor = Color.White;
			preset.ReflectionColor = Color.White;
			preset.UseAeroEffect = false;
			preset.Opacity = 40;
			preset.InnerOutlineColor = Color.White;
			preset.ShadeColor = Color.Black;
			preset.OverridesThemeSettings = true;
			preset.CalendarBackground = Color.PaleGoldenrod;
			preset.CalendarBorder = Color.Black;
			preset.ItemBorder = Color.Black;
			preset.ItemBackground1 = Color.FromArgb(0x80, 0x90, 0x30, 0x20);
			preset.UseItemBackground2 = false;
			preset.ItemBackground2 = Color.White;
			preset.Theme = ThemeType.Standard;
			AddToList(preset);

			preset = new Preset();
			preset.Name = "Bright Red";
			preset.UseGlassEffect = true;
			preset.GlassEffectType = GlassEffectType.Type4;
			preset.UsePenAsGlow = false;
			preset.GlowColor = Color.Black;
			preset.ReflectionColor = Color.White;
			preset.UseAeroEffect = false;
			preset.Opacity = 40;
			preset.InnerOutlineColor = Color.White;
			preset.ShadeColor = Color.Black;
			preset.OverridesThemeSettings = true;
			preset.CalendarBackground = Color.White;
			preset.CalendarBorder = Color.FromArgb(0x40, 0x0, 0x0);
			preset.ItemBorder = Color.FromArgb(0x60, 0x0, 0x0);
			preset.ItemBackground1 = Color.Red;
			preset.UseItemBackground2 = false;
			preset.ItemBackground2 = Color.White;
			preset.Theme = ThemeType.Standard;
			AddToList(preset);
		}

		private void AddToList(Preset preset)
		{
			ListViewItem item = new ListViewItem();
			item.Text = preset.Name;
			item.Tag = preset;
			presetsList.Items.Add(item);
		}

		private void OnDocumentCompleted(object sender, WebBrowserDocumentCompletedEventArgs e)
		{
			if (_lbInfo.Document != null)
			{
				_lbInfo.Document.Click += Document_Click;
				_lbInfo.Document.Body.Style = "font-family: Verdana, Arial, Helvetica, sans-serif; " +
					"font-size: 7.5pt; margin: 2pt; padding: 0pt; background-color: #ffffee; cursor: default;";
			}
		}

		/// <summary>
		/// Handles the Web browser document's Click event.
		/// </summary>
		private void Document_Click(object sender, HtmlElementEventArgs e)
		{
			e.ReturnValue = true;

			HtmlElement pointed = _lbInfo.Document.GetElementFromPoint(e.ClientMousePosition);
			if (pointed == null)
				return;

			if (pointed.TagName.ToLower() == "a")
			{
				string href = pointed.GetAttribute("href").ToLower();
				if (href.StartsWith("help:"))
				{
					string topic = href.Substring(5);
					string helpFile = ResolveHelpPath(_appPath);

					if (System.IO.File.Exists(helpFile))
					{
						Help.ShowHelp(this, helpFile, HelpNavigator.Topic, topic);

						// Prevent link follow
						e.ReturnValue = false;
					}
				}
			}
		}

		private static string ResolveHelpPath(string baseDir)
		{
			string[] helpFiles = new string[]
			{
				"MindFusion.Scheduling.chm",
				"MindFusion WinForms.chm"
			};

			System.IO.DirectoryInfo dirInfo = new System.IO.DirectoryInfo(baseDir);
			int i = 0;
			while (dirInfo != null)
			{
				string helpFile = System.IO.Path.Combine(dirInfo.FullName, helpFiles[i]);
				if (System.IO.File.Exists(helpFile))
					return helpFile;

				i++;
				if (i == helpFiles.Length)
				{
					i = 0;
					dirInfo = dirInfo.Parent;
				}
			}

			return string.Empty;
		}

		private void OnAbout(object sender, System.EventArgs e)
		{
			System.Reflection.Assembly assembly = System.Reflection.Assembly.GetAssembly(
				typeof(MindFusion.Scheduling.WinForms.Calendar));

			if (assembly == null)
				return;

			Type aboutFormType = assembly.GetType(
				"MindFusion.Scheduling.WinForms.AboutForm");

			if (aboutFormType == null)
				return;

			((Form)Activator.CreateInstance(aboutFormType)).ShowDialog(this);
		}

		private void OnExit(object sender, System.EventArgs e)
		{
			this.Close();
		}

		private void presetsList_ItemCheck(object sender, ItemCheckEventArgs e)
		{
			if (suspendUpdates)
				return;

			if (e.NewValue == CheckState.Checked)
			{
				// Uncheck all other items
				suspendUpdates = true;
				for (int i = 0; i < presetsList.Items.Count; i++)
				{
					if (i != e.Index)
						presetsList.Items[i].Checked = false;
				}
				suspendUpdates = false;

				ApplyPreset(presetsList.Items[e.Index].Tag as Preset);
			}
			else
			{
				ApplyPreset(defaultPreset);
			}
		}
		private bool suspendUpdates = false;

		private void checkBox1_CheckedChanged(object sender, EventArgs e)
		{
			if (checkBox1.Checked)
				_schedule.ItemEffects.Add(glassEffect);
			else
				_schedule.ItemEffects.Remove(glassEffect);
		}

		private void comboBox1_SelectedIndexChanged(object sender, EventArgs e)
		{
			glassEffect.Type = (GlassEffectType)comboBox1.SelectedIndex;
		}

		private void checkBox2_CheckedChanged(object sender, EventArgs e)
		{
			glassEffect.UsePenAsGlow = checkBox2.Checked;
		}

		private void colorPicker1_ColorChanged(object sender, EventArgs e)
		{
			glassEffect.GlowColor = colorPicker1.Color;
		}

		private void colorPicker2_ColorChanged(object sender, EventArgs e)
		{
			glassEffect.ReflectionColor = colorPicker2.Color;
		}

		private void checkBox3_CheckedChanged(object sender, EventArgs e)
		{
			if (checkBox3.Checked)
				_schedule.ItemEffects.Add(aeroEffect);
			else
				_schedule.ItemEffects.Remove(aeroEffect);
		}

		private void numericUpDown1_ValueChanged(object sender, EventArgs e)
		{
			aeroEffect.Opacity = (float)numericUpDown1.Value / 100;
		}

		private void colorPicker4_ColorChanged(object sender, EventArgs e)
		{
			aeroEffect.InnerOutlineColor = colorPicker4.Color;
		}

		private void colorPicker3_ColorChanged(object sender, EventArgs e)
		{
			aeroEffect.ShadeColor = colorPicker3.Color;
		}

		private void checkBox4_CheckedChanged(object sender, EventArgs e)
		{
			if (checkBox4.Checked)
			{
				SetStyleBrushes(_schedule.TimetableSettings.CellStyle,
					new MindFusion.Drawing.SolidBrush(colorPicker5.Color));
				SetStyleBrushes(_schedule.TimetableSettings.WorkTimeCellStyle,
					new MindFusion.Drawing.SolidBrush(colorPicker5.Color));
				_schedule.TimetableSettings.DayHeaderBrush =
					new MindFusion.Drawing.SolidBrush(colorPicker5.Color);
				SetStyleBorders(_schedule.TimetableSettings.CellStyle, colorPicker9.Color);
				SetStyleBorders(_schedule.TimetableSettings.WorkTimeCellStyle, colorPicker9.Color);
				SetStyleBorders(_schedule.ItemSettings.Style, colorPicker7.Color);
				SetStyleBorders(_schedule.ItemSettings.SelectedItemStyle, colorPicker7.Color);
				SetStyleBorders(_schedule.ItemSettings.PointedItemStyle, colorPicker7.Color);
				SetStyleBorders(_schedule.ItemSettings.PointedSelectedItemStyle, colorPicker7.Color);
				_schedule.ItemSettings.Style.LineColor = colorPicker7.Color;
				_schedule.ItemSettings.SelectedItemStyle.LineColor = colorPicker7.Color;
				_schedule.ItemSettings.PointedItemStyle.LineColor = colorPicker7.Color;
				_schedule.ItemSettings.PointedSelectedItemStyle.LineColor = colorPicker7.Color;
				_schedule.ItemSettings.Style.TextColor = colorPicker7.Color;
				_schedule.ItemSettings.SelectedItemStyle.TextColor = colorPicker7.Color;
				_schedule.ItemSettings.PointedItemStyle.TextColor = colorPicker7.Color;
				_schedule.ItemSettings.PointedSelectedItemStyle.TextColor = colorPicker7.Color;
				_schedule.ItemSettings.Style.HeaderTextColor = colorPicker7.Color;
				_schedule.ItemSettings.SelectedItemStyle.HeaderTextColor = colorPicker7.Color;
				_schedule.ItemSettings.PointedItemStyle.HeaderTextColor = colorPicker7.Color;
				_schedule.ItemSettings.PointedSelectedItemStyle.HeaderTextColor = colorPicker7.Color;
				UpdateItemBrush();
			}
			else
			{
				ResetStyleBrushes(_schedule.TimetableSettings.CellStyle);
				ResetStyleBrushes(_schedule.TimetableSettings.WorkTimeCellStyle);
				_schedule.TimetableSettings.DayHeaderBrush = null;
				ResetStyleBorders(_schedule.TimetableSettings.CellStyle);
				ResetStyleBorders(_schedule.TimetableSettings.WorkTimeCellStyle);

				ResetStyleBorders(_schedule.ItemSettings.Style);
				ResetStyleBorders(_schedule.ItemSettings.SelectedItemStyle);
				ResetStyleBorders(_schedule.ItemSettings.PointedItemStyle);
				ResetStyleBorders(_schedule.ItemSettings.PointedSelectedItemStyle);
				_schedule.ItemSettings.Style.LineColor = Color.Empty;
				_schedule.ItemSettings.SelectedItemStyle.LineColor = Color.Empty;
				_schedule.ItemSettings.PointedItemStyle.LineColor = Color.Empty;
				_schedule.ItemSettings.PointedSelectedItemStyle.LineColor = Color.Empty;
				_schedule.ItemSettings.Style.TextColor = Color.Empty;
				_schedule.ItemSettings.SelectedItemStyle.TextColor = Color.Empty;
				_schedule.ItemSettings.PointedItemStyle.TextColor = Color.Empty;
				_schedule.ItemSettings.PointedSelectedItemStyle.TextColor = Color.Empty;
				_schedule.ItemSettings.Style.HeaderTextColor = Color.Empty;
				_schedule.ItemSettings.SelectedItemStyle.HeaderTextColor = Color.Empty;
				_schedule.ItemSettings.PointedItemStyle.HeaderTextColor = Color.Empty;
				_schedule.ItemSettings.PointedSelectedItemStyle.HeaderTextColor = Color.Empty;

				ResetStyleBrushes(_schedule.ItemSettings.Style);
				ResetStyleBrushes(_schedule.ItemSettings.SelectedItemStyle);
				ResetStyleBrushes(_schedule.ItemSettings.PointedItemStyle);
				ResetStyleBrushes(_schedule.ItemSettings.PointedSelectedItemStyle);
				_schedule.ItemSettings.Style.FillColor = Color.Empty;
				_schedule.ItemSettings.SelectedItemStyle.FillColor = Color.Empty;
				_schedule.ItemSettings.PointedItemStyle.FillColor = Color.Empty;
				_schedule.ItemSettings.PointedSelectedItemStyle.FillColor = Color.Empty;
			}
		}

		private void colorPicker5_ColorChanged(object sender, EventArgs e)
		{
			if (!checkBox4.Checked)
				return;

			SetStyleBrushes(_schedule.TimetableSettings.CellStyle,
				new MindFusion.Drawing.SolidBrush(colorPicker5.Color));
			SetStyleBrushes(_schedule.TimetableSettings.WorkTimeCellStyle,
				new MindFusion.Drawing.SolidBrush(colorPicker5.Color));
			_schedule.TimetableSettings.DayHeaderBrush =
				new MindFusion.Drawing.SolidBrush(colorPicker5.Color);
		}

		private void colorPicker9_ColorChanged(object sender, EventArgs e)
		{
			if (!checkBox4.Checked)
				return;

			SetStyleBorders(_schedule.TimetableSettings.CellStyle, colorPicker9.Color);
			SetStyleBorders(_schedule.TimetableSettings.WorkTimeCellStyle, colorPicker9.Color);
		}

		private void colorPicker7_ColorChanged(object sender, EventArgs e)
		{
			if (!checkBox4.Checked)
				return;

			SetStyleBorders(_schedule.ItemSettings.Style, colorPicker7.Color);
			SetStyleBorders(_schedule.ItemSettings.SelectedItemStyle, colorPicker7.Color);
			SetStyleBorders(_schedule.ItemSettings.PointedItemStyle, colorPicker7.Color);
			SetStyleBorders(_schedule.ItemSettings.PointedSelectedItemStyle, colorPicker7.Color);

			_schedule.ItemSettings.Style.LineColor = colorPicker7.Color;
			_schedule.ItemSettings.SelectedItemStyle.LineColor = colorPicker7.Color;
			_schedule.ItemSettings.PointedItemStyle.LineColor = colorPicker7.Color;
			_schedule.ItemSettings.PointedSelectedItemStyle.LineColor = colorPicker7.Color;

			_schedule.ItemSettings.Style.TextColor = colorPicker7.Color;
			_schedule.ItemSettings.SelectedItemStyle.TextColor = colorPicker7.Color;
			_schedule.ItemSettings.PointedItemStyle.TextColor = colorPicker7.Color;
			_schedule.ItemSettings.PointedSelectedItemStyle.TextColor = colorPicker7.Color;

			_schedule.ItemSettings.Style.HeaderTextColor = colorPicker7.Color;
			_schedule.ItemSettings.SelectedItemStyle.HeaderTextColor = colorPicker7.Color;
			_schedule.ItemSettings.PointedItemStyle.HeaderTextColor = colorPicker7.Color;
			_schedule.ItemSettings.PointedSelectedItemStyle.HeaderTextColor = colorPicker7.Color;
		}

		private void colorPicker6_ColorChanged(object sender, EventArgs e)
		{
			if (!checkBox4.Checked)
				return;

			UpdateItemBrush();
		}

		private void checkBox6_CheckedChanged(object sender, EventArgs e)
		{
			if (!checkBox4.Checked)
				return;

			UpdateItemBrush();
			colorPicker8.Enabled = checkBox6.Checked;
		}

		private void colorPicker8_ColorChanged(object sender, EventArgs e)
		{
			if (!checkBox4.Checked)
				return;

			UpdateItemBrush();
		}

		private void radioButton1_CheckedChanged(object sender, EventArgs e)
		{
			_schedule.Theme = ThemeType.Standard;
		}

		private void radioButton2_CheckedChanged(object sender, EventArgs e)
		{
			_schedule.Theme = ThemeType.Windows2003;
		}

		private void radioButton3_CheckedChanged(object sender, EventArgs e)
		{
			_schedule.Theme = ThemeType.Lila;
		}

		private void radioButton4_CheckedChanged(object sender, EventArgs e)
		{
			_schedule.Theme = ThemeType.Silver;
		}

		private void radioButton5_CheckedChanged(object sender, EventArgs e)
		{
			_schedule.Theme = ThemeType.Vista;
		}

		private void radioButton6_CheckedChanged(object sender, EventArgs e)
		{
			_schedule.Theme = ThemeType.Light;
		}

		private void UpdateItemBrush()
		{
			MindFusion.Drawing.Brush brush = null;
			if (!checkBox6.Checked)
			{
				brush = new MindFusion.Drawing.SolidBrush(colorPicker6.Color);
			}
			else
			{
				brush = new MindFusion.Drawing.LinearGradientBrush(
					colorPicker6.Color, colorPicker8.Color, 90);
			}

			SetStyleBrushes(_schedule.ItemSettings.Style, brush);
			SetStyleBrushes(_schedule.ItemSettings.SelectedItemStyle, brush);
			SetStyleBrushes(_schedule.ItemSettings.PointedItemStyle, brush);
			SetStyleBrushes(_schedule.ItemSettings.PointedSelectedItemStyle, brush);

			_schedule.ItemSettings.Style.FillColor = colorPicker6.Color;
			_schedule.ItemSettings.SelectedItemStyle.FillColor = colorPicker6.Color;
			_schedule.ItemSettings.PointedItemStyle.FillColor = colorPicker6.Color;
			_schedule.ItemSettings.PointedSelectedItemStyle.FillColor = colorPicker6.Color;
		}

		private void SetStyleBorders(Style style, Color color)
		{
			style.BorderLeftColor = color;
			style.BorderTopColor = color;
			style.BorderRightColor = color;
			style.BorderBottomColor = color;
			style.HeaderBorderLeftColor = color;
			style.HeaderBorderTopColor = color;
			style.HeaderBorderRightColor = color;
			style.HeaderBorderBottomColor = color;
		}

		private void SetStyleBrushes(Style style, MindFusion.Drawing.Brush brush)
		{
			style.Brush = brush;
			style.HeaderBrush = brush;
		}

		private void ResetStyleBorders(Style style)
		{
			style.BorderLeftColor = Color.Empty;
			style.BorderTopColor = Color.Empty;
			style.BorderRightColor = Color.Empty;
			style.BorderBottomColor = Color.Empty;
			style.HeaderBorderLeftColor = Color.Empty;
			style.HeaderBorderTopColor = Color.Empty;
			style.HeaderBorderRightColor = Color.Empty;
			style.HeaderBorderBottomColor = Color.Empty;
		}

		private void ResetStyleBrushes(Style style)
		{
			style.Brush = null;
			style.HeaderBrush = null;
		}

		private void ApplyPreset(Preset preset)
		{
			checkBox1.Checked = preset.UseGlassEffect;
			comboBox1.SelectedIndex = (int)preset.GlassEffectType;
			checkBox2.Checked = preset.UsePenAsGlow;
			colorPicker1.Color = preset.GlowColor;
			colorPicker2.Color = preset.ReflectionColor;

			checkBox3.Checked = preset.UseAeroEffect;
			numericUpDown1.Value = preset.Opacity;
			colorPicker3.Color = preset.ShadeColor;
			colorPicker4.Color = preset.InnerOutlineColor;

			checkBox4.Checked = preset.OverridesThemeSettings;
			colorPicker5.Color = preset.CalendarBackground;
			colorPicker9.Color = preset.CalendarBorder;
			colorPicker7.Color = preset.ItemBorder;
			colorPicker6.Color = preset.ItemBackground1;
			checkBox6.Checked = preset.UseItemBackground2;
			colorPicker8.Color = preset.ItemBackground2;

			if (preset.Theme.HasValue)
			{
				switch (preset.Theme.Value)
				{

					case ThemeType.Standard:
						radioButton1.Checked = true;
						break;

					case ThemeType.Windows2003:
						radioButton2.Checked = true;
						break;

					case ThemeType.Lila:
						radioButton3.Checked = true;
						break;

					case ThemeType.Silver:
						radioButton4.Checked = true;
						break;

					case ThemeType.Vista:
						radioButton5.Checked = true;
						break;

					case ThemeType.Light:
						radioButton6.Checked = true;
						break;

				}
			}
		}


		private GlassEffect glassEffect;
		private AeroEffect aeroEffect;
		private Preset defaultPreset;

		private class Preset
		{
			public string Name;

			// Glass
			public bool UseGlassEffect;
			public GlassEffectType GlassEffectType;
			public bool UsePenAsGlow;
			public Color GlowColor;
			public Color ReflectionColor;

			// Aero
			public bool UseAeroEffect;
			public int Opacity;
			public Color InnerOutlineColor;
			public Color ShadeColor;

			// Misc
			public bool OverridesThemeSettings;
			public Color CalendarBackground;
			public Color CalendarBorder;
			public Color ItemBorder;
			public Color ItemBackground1;
			public bool UseItemBackground2;
			public Color ItemBackground2;

			public Nullable<ThemeType> Theme = null;
		}


		private string _appPath;
	}
}
